import 'abortcontroller-polyfill/dist/polyfill-patch-fetch';
declare abstract class Fetch {
    abstract get(url: string, data: any, options: IOptions): Promise<any>;
    abstract post(url: string, data: any, options: IOptions): Promise<any>;
    abstract getData(url: string, data: any, options: IOptions): Promise<any>;
    abstract postData(url: string, data: any, options: IOptions): Promise<any>;
    abstract postFormData(url: string, data: any, options: IOptions): Promise<any>;
    abstract createRequest(url: string, data: any, options: IOptions): Promise<any>;
}
declare type Tcredentials = 'omit' | 'same-origin' | 'include';
declare type TMethods = 'GET' | 'POST' | 'DELETE' | 'PUT' | 'OPTIONS' | 'PATCH' | 'TRACE' | 'CONNECT' | 'HEAD';
declare type TDataType = 'json' | null;
interface IOptions {
    /**
     * 请求方法
     */
    method?: TMethods;
    /**
     * fetch 的 mode
     */
    mode?: string;
    /**
     * 请求的头信息
     */
    headers?: any;
    /**
     * 请求的 credentials，如 omit、same-origin 或者 include。为了在当前域名内自动发送 cookie
     */
    credentials?: Tcredentials;
    /**
     * 是否进行接口数据缓存
     */
    cache?: boolean;
    /**
     * 是否支持可abort取消请求
     */
    canAbort?: boolean;
    /**
     * AbortContronller的signal
     */
    signal?: any;
    /**
     * 请求的 body 信息
     */
    body?: any;
    /**
     * 请求超时时间ms
     */
    timeout?: number;
    /**
     * 去除headers中的ContentType
     */
    noContentType?: boolean;
    /**
     * 传递的数据格式
     */
    dataType?: TDataType;
}
interface IConstructor {
    defalutParams?: any;
    defaultOptions?: IOptions;
    baseUrl?: string;
    transformGetData?: (any: any) => string;
    httpCodeMessage?: IHttpCodeMessage;
}
interface IHttpCodeMessage {
    [key: number]: string;
}
declare class AcmeFetch extends Fetch {
    /**
     * 请求的实例
     */
    private instance;
    /**
     * 默认传给后端的参数（比如说token、uuid等）
     */
    private defaultParams;
    /**
     * 默认的请求配置项
     */
    private defaultOptions;
    /**
     * 基础请求地址
     */
    private baseUrl;
    /**
     * 缓存数据的队列
     */
    private cacheDataQueue;
    private cacheUrlQueue;
    private limit;
    /**
     * 取消请求对应的Abort contronller
     */
    private controllerMap;
    /**
     * http请求默认的错误码对应的提示信息
     */
    private httpCodeMessage;
    constructor({ defalutParams, defaultOptions, baseUrl, transformGetData, httpCodeMessage }: IConstructor);
    /**
     * 处理为get格式的请求参数
     * @param data 需要传递给后端的数据对象
     */
    private transformGetData;
    /**
     * 默认处理接口返回的json数据
     * @param data 后端返回的json数据
     */
    private defaultHandleResponse;
    /**
     * 对接口的返回进行状态检查
     * @param response response对象
     */
    private checkResponse;
    /**
     * 为了达到timout超时的目的，增加一个timeout Promise
     * @param timeout 超时时间
     */
    private createTimeoutPromise;
    /**
     * 创建一个请求，基础API
     * @param url 请求地址
     * @param data 请求body
     * @param options 请求options
     */
    createRequest(url: any, data?: any, options?: IOptions): any;
    /**
     * get请求返回的是response
     * @param url 请求地址
     * @param data 传给后端的数据
     * @param options 请求方法的配置项
     */
    get(url: string, data?: any, options?: IOptions): Promise<any>;
    /**
     * get请求返回的是defaultHandleResponse处理后的结果(前提是json格式的返回结果)
     * @param url 请求地址
     * @param data 传给后端的数据
     * @param options 请求方法的配置项
     */
    getData(url: string, data?: any, options?: IOptions): Promise<any>;
    /**
     * post请求返回的是response
     * @param url 请求地址
     * @param data 传给后端的数据
     * @param options 请求方法的配置项
     */
    post(url: string, data?: any, options?: IOptions): Promise<any>;
    /**
     * post请求回的是defaultHandleResponse处理后的结果(前提是json格式的返回结果)
     * @param url 请求地址
     * @param data 传给后端的数据
     * @param options 请求方法的配置项
     */
    postData(url: string, data?: any, options?: IOptions): Promise<any>;
    /**
     * postFormData: 请求传递formdata的格式数据
     * @param url 请求地址
     * @param data 传给后端的数据
     * @param options 请求方法的配置项
     */
    postFormData(url: string, data?: any, options?: IOptions): Promise<any>;
    /**
     * 增加cache的数据
     * @param url 请求的url也就是缓存对应的key
     * @param data 需要缓存的数据
     */
    addCacheData(url: string, data?: any): void;
    /**
     * 获取cache的数据
     * @param url 请求的url也就是缓存对应的key
     */
    getCacheData(url: string): any;
    /**
     * 获取缓存的队列信息（如果你有持久化的需求）
     */
    getCacheQueue(): [Array<any>, Array<any>];
    /**
     * 手动设置缓存队列的信息
     * @param cacheDataQueue 缓存的data队列
     * @param cacheUrlQueue 缓存的url队列
     */
    setCacheQueue(cacheDataQueue: Array<any>, cacheUrlQueue: Array<any>): void;
    /**
     * 设置缓存队列的长度
     * @param {number} limit 队列的长度
     */
    setLimit(limit: number): void;
    /**
     * 获取请求的AortController可以进行请求abort操作
     * @param key 请求的url
     */
    getAortController(key: string): any;
    /**
     * 清除我们的缓存队列
     */
    clearCache(): void;
    /**
     * 清除我们的缓存队列以及缓存的abortContronller
     */
    clearAll(): void;
}
/**
 * cover 住我们的await prmise场景
 */
declare const useAwaitPromise: (promise: any) => any;
export { useAwaitPromise };
export default AcmeFetch;
