import sourceMaps from 'rollup-plugin-sourcemaps';
import typescript from 'rollup-plugin-typescript2';
import resolve from '@rollup/plugin-node-resolve';
import commonjs from 'rollup-plugin-commonjs';
import clear from 'rollup-plugin-clear';
import { terser } from 'rollup-plugin-terser';
import { name } from './package.json';

export default {
  input: './src/index.ts',
  output: [
    { format: 'es', file: 'lib/index.esm.js', sourcemap: true },
    { format: 'umd', file: 'lib/index.umd.js', name, sourcemap: true }
  ],
  onwarn: function (warning) {
    if (warning.code === 'THIS_IS_UNDEFINED') {
      return;
    }
    console.error(warning.message);
  },
  plugins: [
    clear({
      targets: ['lib']
    }),
    resolve({
      // 将自定义选项传递给解析插件
      customResolveOptions: {
        moduleDirectory: 'node_modules'
      }
    }),
    typescript({
      useTsconfigDeclarationDir: true
    }),
    commonjs(),
    sourceMaps(),
    terser()
  ],
  // 一些外部的peer dependency不要进行打包
  external: []
};
